@@ -12,8 +12,8 @@
 #'
 #' @author Rob J Hyndman
 #' @examples
-#' fnaive <- aus_mortality |>
-#'   dplyr::filter(State == "Victoria", Sex == "female") |>
+#' fnaive <- norway_mortality |>
+#'   dplyr::filter(Sex == "Female") |>
 #'   model(fit = FNAIVE(Mortality))
 #' report(fnaive)
 #' autoplot(fnaive) + ggplot2::scale_y_log10()
@@ -31,7 +31,7 @@ train_fnaive <- function(.data, ...) {
   measures <- measures[!(measures %in% c(agevar, vvar$population))]
   measure <- measures[1]
   last_measure <- .data |>
-    tibble::as_tibble() |>
+    tsibble::as_tibble() |>
     dplyr::mutate(index = .data[[indexvar]] + 1)
   last_measure <- last_measure[, c("index", agevar, measure)]
   colnames(last_measure) <- c(indexvar, agevar, ".fitted")
@@ -63,9 +63,15 @@ train_fnaive <- function(.data, ...) {
 #' @rdname forecast
 #' @export
 forecast.FNAIVE <- function(
-    object, new_data = NULL, h = NULL,
-    point_forecast = list(.mean = mean),
-    simulate = FALSE, bootstrap = FALSE, times = 5000, ...) {
+  object,
+  new_data = NULL,
+  h = NULL,
+  point_forecast = list(.mean = mean),
+  simulate = FALSE,
+  bootstrap = FALSE,
+  times = 5000,
+  ...
+) {
   # simulation/bootstrap not actually used here as forecast.mdl_vtl_ts
   # handles this using generate() and forecast.LC is never called.
   # The arguments are included so they show in the docs
@@ -98,8 +104,13 @@ forecast.FNAIVE <- function(
 
 #' @export
 generate.FNAIVE <- function(
-    x, new_data = NULL, h = NULL,
-    bootstrap = FALSE, times = 1, ...) {
+  x,
+  new_data = NULL,
+  h = NULL,
+  bootstrap = FALSE,
+  times = 1,
+  ...
+) {
   agevar <- age_var(new_data)
   indexvar <- index_var(x$fitted)
   h <- length(unique(new_data[[indexvar]]))
@@ -108,11 +119,11 @@ generate.FNAIVE <- function(
     stop("We have a problem")
   }
   measure <- colnames(x$fitted)[3]
-  setup <- x$fitted[,c(indexvar, agevar, measure, ".innov")] |>
+  setup <- x$fitted[, c(indexvar, agevar, measure, ".innov")] |>
     left_join(x$model, by = agevar) |>
     tidyr::expand_grid(.rep = unique(new_data$.rep)) |>
     group_by(!!sym(agevar), .rep)
-  if(bootstrap) {
+  if (bootstrap) {
     out <- setup |>
       dplyr::group_modify(function(x, ...) {
         measure <- colnames(x)[[2]]
@@ -125,7 +136,7 @@ generate.FNAIVE <- function(
         measure <- colnames(x)[[2]]
         innov <- stats::rnorm(n = h, sd = x$sigma[1])
         tibble(horizon = seq(h), .sim = tail(x[[measure]], 1) + cumsum(innov))
-    })
+      })
   }
   new_data$horizon <- new_data[[indexvar]] - min(new_data[[indexvar]]) + 1
   new_data |>
@@ -158,9 +169,13 @@ model_sum.FNAIVE <- function(x) {
 autoplot.FNAIVE <- function(object, age = "Age", ...) {
   modelname <- attributes(object)$model
   object <- object |>
-    mutate(out = purrr::map(object[[modelname]], function(x){x$fit$model}))
+    mutate(
+      out = purrr::map(object[[modelname]], function(x) {
+        x$fit$model
+      })
+    )
   object[[modelname]] <- NULL
-  object <- object  |>
+  object <- object |>
     tidyr::unnest("out")
   keys <- colnames(object)
   keys <- keys[!(keys %in% c("sigma", age))]
@@ -173,7 +188,10 @@ autoplot.FNAIVE <- function(object, age = "Age", ...) {
     geom_line() +
     ggplot2::labs(x = age, y = "Sigma")
   if (nk > 1) {
-    p <- p + ggplot2::guides(colour = ggplot2::guide_legend(paste0(keys, collapse = "/")))
+    p <- p +
+      ggplot2::guides(
+        colour = ggplot2::guide_legend(paste0(keys, collapse = "/"))
+      )
   }
   p
 }
@@ -182,7 +200,11 @@ autoplot.FNAIVE <- function(object, age = "Age", ...) {
 age_components.FNAIVE <- function(object, ...) {
   modelname <- attributes(object)$model
   object <- object |>
-    mutate(out = purrr::map(object[[modelname]], function(x){x$fit$model})) |>
+    mutate(
+      out = purrr::map(object[[modelname]], function(x) {
+        x$fit$model
+      })
+    ) |>
     as_tibble()
   object[[modelname]] <- NULL
   object |> tidyr::unnest("out")
@@ -193,4 +215,12 @@ time_components.FNAIVE <- function(object, ...) {
   stop("FNAIVE objects have no time components")
 }
 
-globalVariables(c(".resid", "sigma", "std.error", "stat", ".innov", "fit", "horizon"))
+globalVariables(c(
+  ".resid",
+  "sigma",
+  "std.error",
+  "stat",
+  ".innov",
+  "fit",
+  "horizon"
+))
